@@ -13,5 +13,5 @@ pub struct Paging {
 }
 
 pub trait Pageable {
-    fn start_from(self, starting_point: Paging) -> Self;
+    fn start_from(self, starting_point: Option<PagingCursor>) -> Self;
 }
